==> snapd-glib_1.63.orig.tar.gz: snapd-glib-1.63/snapd-glib/snapd-version.h <==
/*
 * Copyright (C) 2017 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#ifndef __SNAPD_GLIB_VERSION_H__
#define __SNAPD_GLIB_VERSION_H__

#if !defined(__SNAPD_GLIB_INSIDE__) && !defined(SNAPD_COMPILATION)
#error "Only <snapd-glib/snapd-glib.h> can be included directly."
#endif

/**
 * SNAPD_GLIB_VERSION_1_0:
 *
 * A define that can be used by the C pre-processor to check for features in 1.0
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_0

/**
 * SNAPD_GLIB_VERSION_1_1:
 *
 * A define that can be used by the C pre-processor to check for features in 1.1
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_1

/**
 * SNAPD_GLIB_VERSION_1_2:
 *
 * A define that can be used by the C pre-processor to check for features in 1.2
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_2

/**
 * SNAPD_GLIB_VERSION_1_3:
 *
 * A define that can be used by the C pre-processor to check for features in 1.3
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_3

/**
 * SNAPD_GLIB_VERSION_1_4:
 *
 * A define that can be used by the C pre-processor to check for features in 1.4
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_4

/**
 * SNAPD_GLIB_VERSION_1_5:
 *
 * A define that can be used by the C pre-processor to check for features in 1.5
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_5

/**
 * SNAPD_GLIB_VERSION_1_6:
 *
 * A define that can be used by the C pre-processor to check for features in 1.6
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_6

/**
 * SNAPD_GLIB_VERSION_1_7:
 *
 * A define that can be used by the C pre-processor to check for features in 1.7
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_7

/**
 * SNAPD_GLIB_VERSION_1_8:
 *
 * A define that can be used by the C pre-processor to check for features in 1.8
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_8

/**
 * SNAPD_GLIB_VERSION_1_9:
 *
 * A define that can be used by the C pre-processor to check for features in 1.9
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_9

/**
 * SNAPD_GLIB_VERSION_1_10:
 *
 * A define that can be used by the C pre-processor to check for features in 1.10
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_10

/**
 * SNAPD_GLIB_VERSION_1_11:
 *
 * A define that can be used by the C pre-processor to check for features in 1.11
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_11

/**
 * SNAPD_GLIB_VERSION_1_12:
 *
 * A define that can be used by the C pre-processor to check for features in 1.12
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_12

/**
 * SNAPD_GLIB_VERSION_1_13:
 *
 * A define that can be used by the C pre-processor to check for features in 1.13
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_13

/**
 * SNAPD_GLIB_VERSION_1_14:
 *
 * A define that can be used by the C pre-processor to check for features in 1.14
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_14

/**
 * SNAPD_GLIB_VERSION_1_15:
 *
 * A define that can be used by the C pre-processor to check for features in 1.15
 *
 * Since: 1.15
 */
#define SNAPD_GLIB_VERSION_1_15

/**
 * SNAPD_GLIB_VERSION_1_16:
 *
 * A define that can be used by the C pre-processor to check for features in 1.16
 *
 * Since: 1.16
 */
#define SNAPD_GLIB_VERSION_1_16

/**
 * SNAPD_GLIB_VERSION_1_17:
 *
 * A define that can be used by the C pre-processor to check for features in 1.17
 *
 * Since: 1.17
 */
#define SNAPD_GLIB_VERSION_1_17

/**
 * SNAPD_GLIB_VERSION_1_18:
 *
 * A define that can be used by the C pre-processor to check for features in 1.18
 *
 * Since: 1.18
 */
#define SNAPD_GLIB_VERSION_1_18

/**
 * SNAPD_GLIB_VERSION_1_19:
 *
 * A define that can be used by the C pre-processor to check for features in 1.19
 *
 * Since: 1.19
 */
#define SNAPD_GLIB_VERSION_1_19

/**
 * SNAPD_GLIB_VERSION_1_20:
 *
 * A define that can be used by the C pre-processor to check for features in 1.20
 *
 * Since: 1.20
 */
#define SNAPD_GLIB_VERSION_1_20

/**
 * SNAPD_GLIB_VERSION_1_21:
 *
 * A define that can be used by the C pre-processor to check for features in 1.21
 *
 * Since: 1.21
 */
#define SNAPD_GLIB_VERSION_1_21

/**
 * SNAPD_GLIB_VERSION_1_22:
 *
 * A define that can be used by the C pre-processor to check for features in 1.22
 *
 * Since: 1.22
 */
#define SNAPD_GLIB_VERSION_1_22

/**
 * SNAPD_GLIB_VERSION_1_23:
 *
 * A define that can be used by the C pre-processor to check for features in 1.23
 *
 * Since: 1.23
 */
#define SNAPD_GLIB_VERSION_1_23

/**
 * SNAPD_GLIB_VERSION_1_24:
 *
 * A define that can be used by the C pre-processor to check for features in 1.24
 *
 * Since: 1.24
 */
#define SNAPD_GLIB_VERSION_1_24

/**
 * SNAPD_GLIB_VERSION_1_25:
 *
 * A define that can be used by the C pre-processor to check for features in 1.25
 *
 * Since: 1.25
 */
#define SNAPD_GLIB_VERSION_1_25

/**
 * SNAPD_GLIB_VERSION_1_26:
 *
 * A define that can be used by the C pre-processor to check for features in 1.26
 *
 * Since: 1.26
 */
#define SNAPD_GLIB_VERSION_1_26

/**
 * SNAPD_GLIB_VERSION_1_27:
 *
 * A define that can be used by the C pre-processor to check for features in 1.27
 *
 * Since: 1.27
 */
#define SNAPD_GLIB_VERSION_1_27

/**
 * SNAPD_GLIB_VERSION_1_28:
 *
 * A define that can be used by the C pre-processor to check for features in 1.28
 *
 * Since: 1.28
 */
#define SNAPD_GLIB_VERSION_1_28

/**
 * SNAPD_GLIB_VERSION_1_29:
 *
 * A define that can be used by the C pre-processor to check for features in 1.29
 *
 * Since: 1.29
 */
#define SNAPD_GLIB_VERSION_1_29

/**
 * SNAPD_GLIB_VERSION_1_30:
 *
 * A define that can be used by the C pre-processor to check for features in 1.30
 *
 * Since: 1.30
 */
#define SNAPD_GLIB_VERSION_1_30

/**
 * SNAPD_GLIB_VERSION_1_31:
 *
 * A define that can be used by the C pre-processor to check for features in 1.31
 *
 * Since: 1.31
 */
#define SNAPD_GLIB_VERSION_1_31

/**
 * SNAPD_GLIB_VERSION_1_32:
 *
 * A define that can be used by the C pre-processor to check for features in 1.32
 *
 * Since: 1.32
 */
#define SNAPD_GLIB_VERSION_1_32

/**
 * SNAPD_GLIB_VERSION_1_33:
 *
 * A define that can be used by the C pre-processor to check for features in 1.33
 *
 * Since: 1.33
 */
#define SNAPD_GLIB_VERSION_1_33

/**
 * SNAPD_GLIB_VERSION_1_34:
 *
 * A define that can be used by the C pre-processor to check for features in 1.34
 *
 * Since: 1.34
 */
#define SNAPD_GLIB_VERSION_1_34

/**
 * SNAPD_GLIB_VERSION_1_35:
 *
 * A define that can be used by the C pre-processor to check for features in 1.35
 *
 * Since: 1.35
 */
#define SNAPD_GLIB_VERSION_1_35

/**
 * SNAPD_GLIB_VERSION_1_36:
 *
 * A define that can be used by the C pre-processor to check for features in 1.36
 *
 * Since: 1.36
 */
#define SNAPD_GLIB_VERSION_1_36

/**
 * SNAPD_GLIB_VERSION_1_37:
 *
 * A define that can be used by the C pre-processor to check for features in 1.37
 *
 * Since: 1.37
 */
#define SNAPD_GLIB_VERSION_1_37

/**
 * SNAPD_GLIB_VERSION_1_38:
 *
 * A define that can be used by the C pre-processor to check for features in 1.38
 *
 * Since: 1.38
 */
#define SNAPD_GLIB_VERSION_1_38

/**
 * SNAPD_GLIB_VERSION_1_39:
 *
 * A define that can be used by the C pre-processor to check for features in 1.39
 *
 * Since: 1.39
 */
#define SNAPD_GLIB_VERSION_1_39

/**
 * SNAPD_GLIB_VERSION_1_40:
 *
 * A define that can be used by the C pre-processor to check for features in 1.40
 *
 * Since: 1.40
 */
#define SNAPD_GLIB_VERSION_1_40

/**
 * SNAPD_GLIB_VERSION_1_41:
 *
 * A define that can be used by the C pre-processor to check for features in 1.41
 *
 * Since: 1.41
 */
#define SNAPD_GLIB_VERSION_1_41

/**
 * SNAPD_GLIB_VERSION_1_42:
 *
 * A define that can be used by the C pre-processor to check for features in 1.42
 *
 * Since: 1.42
 */
#define SNAPD_GLIB_VERSION_1_42

/**
 * SNAPD_GLIB_VERSION_1_43:
 *
 * A define that can be used by the C pre-processor to check for features in 1.43
 *
 * Since: 1.43
 */
#define SNAPD_GLIB_VERSION_1_43

/**
 * SNAPD_GLIB_VERSION_1_44:
 *
 * A define that can be used by the C pre-processor to check for features in 1.44
 *
 * Since: 1.44
 */
#define SNAPD_GLIB_VERSION_1_44

/**
 * SNAPD_GLIB_VERSION_1_45:
 *
 * A define that can be used by the C pre-processor to check for features in 1.45
 *
 * Since: 1.45
 */
#define SNAPD_GLIB_VERSION_1_45

/**
 * SNAPD_GLIB_VERSION_1_46:
 *
 * A define that can be used by the C pre-processor to check for features in 1.46
 *
 * Since: 1.46
 */
#define SNAPD_GLIB_VERSION_1_46

/**
 * SNAPD_GLIB_VERSION_1_47:
 *
 * A define that can be used by the C pre-processor to check for features in 1.47
 *
 * Since: 1.47
 */
#define SNAPD_GLIB_VERSION_1_47

/**
 * SNAPD_GLIB_VERSION_1_48:
 *
 * A define that can be used by the C pre-processor to check for features in 1.48
 *
 * Since: 1.48
 */
#define SNAPD_GLIB_VERSION_1_48

/**
 * SNAPD_GLIB_VERSION_1_49:
 *
 * A define that can be used by the C pre-processor to check for features in 1.49
 *
 * Since: 1.49
 */
#define SNAPD_GLIB_VERSION_1_49

/**
 * SNAPD_GLIB_VERSION_1_50:
 *
 * A define that can be used by the C pre-processor to check for features in 1.50
 *
 * Since: 1.50
 */
#define SNAPD_GLIB_VERSION_1_50

/**
 * SNAPD_GLIB_VERSION_1_51:
 *
 * A define that can be used by the C pre-processor to check for features in 1.51
 *
 * Since: 1.51
 */
#define SNAPD_GLIB_VERSION_1_51

/**
 * SNAPD_GLIB_VERSION_1_52:
 *
 * A define that can be used by the C pre-processor to check for features in 1.52
 *
 * Since: 1.52
 */
#define SNAPD_GLIB_VERSION_1_52

/**
 * SNAPD_GLIB_VERSION_1_53:
 *
 * A define that can be used by the C pre-processor to check for features in 1.53
 *
 * Since: 1.53
 */
#define SNAPD_GLIB_VERSION_1_53

/**
 * SNAPD_GLIB_VERSION_1_54:
 *
 * A define that can be used by the C pre-processor to check for features in 1.54
 *
 * Since: 1.54
 */
#define SNAPD_GLIB_VERSION_1_54

/**
 * SNAPD_GLIB_VERSION_1_55:
 *
 * A define that can be used by the C pre-processor to check for features in 1.55
 *
 * Since: 1.55
 */
#define SNAPD_GLIB_VERSION_1_55

/**
 * SNAPD_GLIB_VERSION_1_56:
 *
 * A define that can be used by the C pre-processor to check for features in 1.56
 *
 * Since: 1.56
 */
#define SNAPD_GLIB_VERSION_1_56

/**
 * SNAPD_GLIB_VERSION_1_57:
 *
 * A define that can be used by the C pre-processor to check for features in 1.57
 *
 * Since: 1.57
 */
#define SNAPD_GLIB_VERSION_1_57

/**
 * SNAPD_GLIB_VERSION_1_58:
 *
 * A define that can be used by the C pre-processor to check for features in 1.58
 *
 * Since: 1.58
 */
#define SNAPD_GLIB_VERSION_1_58

/**
 * SNAPD_GLIB_VERSION_1_59:
 *
 * A define that can be used by the C pre-processor to check for features in 1.59
 *
 * Since: 1.59
 */
#define SNAPD_GLIB_VERSION_1_59

/**
 * SNAPD_GLIB_VERSION_1_60:
 *
 * A define that can be used by the C pre-processor to check for features in 1.60
 *
 * Since: 1.60
 */
#define SNAPD_GLIB_VERSION_1_60

/**
 * SNAPD_GLIB_VERSION_1_61:
 *
 * A define that can be used by the C pre-processor to check for features in 1.61
 *
 * Since: 1.61
 */
#define SNAPD_GLIB_VERSION_1_61

/**
 * SNAPD_GLIB_VERSION_1_62:
 *
 * A define that can be used by the C pre-processor to check for features in 1.62
 *
 * Since: 1.62
 */
#define SNAPD_GLIB_VERSION_1_62

/**
 * SNAPD_GLIB_VERSION_1_63:
 *
 * A define that can be used by the C pre-processor to check for features in 1.63
 *
 * Since: 1.63
 */
#define SNAPD_GLIB_VERSION_1_63

#endif /* __SNAPD_GLIB_VERSION_H__ */

==> snapd-glib_1.64.orig.tar.gz: snapd-glib-1.64/snapd-glib/snapd-version.h <==
/*
 * Copyright (C) 2017 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#ifndef __SNAPD_GLIB_VERSION_H__
#define __SNAPD_GLIB_VERSION_H__

#if !defined(__SNAPD_GLIB_INSIDE__) && !defined(SNAPD_COMPILATION)
#error "Only <snapd-glib/snapd-glib.h> can be included directly."
#endif

/**
 * SNAPD_GLIB_VERSION_1_0:
 *
 * A define that can be used by the C pre-processor to check for features in 1.0
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_0

/**
 * SNAPD_GLIB_VERSION_1_1:
 *
 * A define that can be used by the C pre-processor to check for features in 1.1
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_1

/**
 * SNAPD_GLIB_VERSION_1_2:
 *
 * A define that can be used by the C pre-processor to check for features in 1.2
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_2

/**
 * SNAPD_GLIB_VERSION_1_3:
 *
 * A define that can be used by the C pre-processor to check for features in 1.3
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_3

/**
 * SNAPD_GLIB_VERSION_1_4:
 *
 * A define that can be used by the C pre-processor to check for features in 1.4
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_4

/**
 * SNAPD_GLIB_VERSION_1_5:
 *
 * A define that can be used by the C pre-processor to check for features in 1.5
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_5

/**
 * SNAPD_GLIB_VERSION_1_6:
 *
 * A define that can be used by the C pre-processor to check for features in 1.6
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_6

/**
 * SNAPD_GLIB_VERSION_1_7:
 *
 * A define that can be used by the C pre-processor to check for features in 1.7
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_7

/**
 * SNAPD_GLIB_VERSION_1_8:
 *
 * A define that can be used by the C pre-processor to check for features in 1.8
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_8

/**
 * SNAPD_GLIB_VERSION_1_9:
 *
 * A define that can be used by the C pre-processor to check for features in 1.9
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_9

/**
 * SNAPD_GLIB_VERSION_1_10:
 *
 * A define that can be used by the C pre-processor to check for features in 1.10
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_10

/**
 * SNAPD_GLIB_VERSION_1_11:
 *
 * A define that can be used by the C pre-processor to check for features in 1.11
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_11

/**
 * SNAPD_GLIB_VERSION_1_12:
 *
 * A define that can be used by the C pre-processor to check for features in 1.12
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_12

/**
 * SNAPD_GLIB_VERSION_1_13:
 *
 * A define that can be used by the C pre-processor to check for features in 1.13
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_13

/**
 * SNAPD_GLIB_VERSION_1_14:
 *
 * A define that can be used by the C pre-processor to check for features in 1.14
 *
 * Since: 1.14
 */
#define SNAPD_GLIB_VERSION_1_14

/**
 * SNAPD_GLIB_VERSION_1_15:
 *
 * A define that can be used by the C pre-processor to check for features in 1.15
 *
 * Since: 1.15
 */
#define SNAPD_GLIB_VERSION_1_15

/**
 * SNAPD_GLIB_VERSION_1_16:
 *
 * A define that can be used by the C pre-processor to check for features in 1.16
 *
 * Since: 1.16
 */
#define SNAPD_GLIB_VERSION_1_16

/**
 * SNAPD_GLIB_VERSION_1_17:
 *
 * A define that can be used by the C pre-processor to check for features in 1.17
 *
 * Since: 1.17
 */
#define SNAPD_GLIB_VERSION_1_17

/**
 * SNAPD_GLIB_VERSION_1_18:
 *
 * A define that can be used by the C pre-processor to check for features in 1.18
 *
 * Since: 1.18
 */
#define SNAPD_GLIB_VERSION_1_18

/**
 * SNAPD_GLIB_VERSION_1_19:
 *
 * A define that can be used by the C pre-processor to check for features in 1.19
 *
 * Since: 1.19
 */
#define SNAPD_GLIB_VERSION_1_19

/**
 * SNAPD_GLIB_VERSION_1_20:
 *
 * A define that can be used by the C pre-processor to check for features in 1.20
 *
 * Since: 1.20
 */
#define SNAPD_GLIB_VERSION_1_20

/**
 * SNAPD_GLIB_VERSION_1_21:
 *
 * A define that can be used by the C pre-processor to check for features in 1.21
 *
 * Since: 1.21
 */
#define SNAPD_GLIB_VERSION_1_21

/**
 * SNAPD_GLIB_VERSION_1_22:
 *
 * A define that can be used by the C pre-processor to check for features in 1.22
 *
 * Since: 1.22
 */
#define SNAPD_GLIB_VERSION_1_22

/**
 * SNAPD_GLIB_VERSION_1_23:
 *
 * A define that can be used by the C pre-processor to check for features in 1.23
 *
 * Since: 1.23
 */
#define SNAPD_GLIB_VERSION_1_23

/**
 * SNAPD_GLIB_VERSION_1_24:
 *
 * A define that can be used by the C pre-processor to check for features in 1.24
 *
 * Since: 1.24
 */
#define SNAPD_GLIB_VERSION_1_24

/**
 * SNAPD_GLIB_VERSION_1_25:
 *
 * A define that can be used by the C pre-processor to check for features in 1.25
 *
 * Since: 1.25
 */
#define SNAPD_GLIB_VERSION_1_25

/**
 * SNAPD_GLIB_VERSION_1_26:
 *
 * A define that can be used by the C pre-processor to check for features in 1.26
 *
 * Since: 1.26
 */
#define SNAPD_GLIB_VERSION_1_26

/**
 * SNAPD_GLIB_VERSION_1_27:
 *
 * A define that can be used by the C pre-processor to check for features in 1.27
 *
 * Since: 1.27
 */
#define SNAPD_GLIB_VERSION_1_27

/**
 * SNAPD_GLIB_VERSION_1_28:
 *
 * A define that can be used by the C pre-processor to check for features in 1.28
 *
 * Since: 1.28
 */
#define SNAPD_GLIB_VERSION_1_28

/**
 * SNAPD_GLIB_VERSION_1_29:
 *
 * A define that can be used by the C pre-processor to check for features in 1.29
 *
 * Since: 1.29
 */
#define SNAPD_GLIB_VERSION_1_29

/**
 * SNAPD_GLIB_VERSION_1_30:
 *
 * A define that can be used by the C pre-processor to check for features in 1.30
 *
 * Since: 1.30
 */
#define SNAPD_GLIB_VERSION_1_30

/**
 * SNAPD_GLIB_VERSION_1_31:
 *
 * A define that can be used by the C pre-processor to check for features in 1.31
 *
 * Since: 1.31
 */
#define SNAPD_GLIB_VERSION_1_31

/**
 * SNAPD_GLIB_VERSION_1_32:
 *
 * A define that can be used by the C pre-processor to check for features in 1.32
 *
 * Since: 1.32
 */
#define SNAPD_GLIB_VERSION_1_32

/**
 * SNAPD_GLIB_VERSION_1_33:
 *
 * A define that can be used by the C pre-processor to check for features in 1.33
 *
 * Since: 1.33
 */
#define SNAPD_GLIB_VERSION_1_33

/**
 * SNAPD_GLIB_VERSION_1_34:
 *
 * A define that can be used by the C pre-processor to check for features in 1.34
 *
 * Since: 1.34
 */
#define SNAPD_GLIB_VERSION_1_34

/**
 * SNAPD_GLIB_VERSION_1_35:
 *
 * A define that can be used by the C pre-processor to check for features in 1.35
 *
 * Since: 1.35
 */
#define SNAPD_GLIB_VERSION_1_35

/**
 * SNAPD_GLIB_VERSION_1_36:
 *
 * A define that can be used by the C pre-processor to check for features in 1.36
 *
 * Since: 1.36
 */
#define SNAPD_GLIB_VERSION_1_36

/**
 * SNAPD_GLIB_VERSION_1_37:
 *
 * A define that can be used by the C pre-processor to check for features in 1.37
 *
 * Since: 1.37
 */
#define SNAPD_GLIB_VERSION_1_37

/**
 * SNAPD_GLIB_VERSION_1_38:
 *
 * A define that can be used by the C pre-processor to check for features in 1.38
 *
 * Since: 1.38
 */
#define SNAPD_GLIB_VERSION_1_38

/**
 * SNAPD_GLIB_VERSION_1_39:
 *
 * A define that can be used by the C pre-processor to check for features in 1.39
 *
 * Since: 1.39
 */
#define SNAPD_GLIB_VERSION_1_39

/**
 * SNAPD_GLIB_VERSION_1_40:
 *
 * A define that can be used by the C pre-processor to check for features in 1.40
 *
 * Since: 1.40
 */
#define SNAPD_GLIB_VERSION_1_40

/**
 * SNAPD_GLIB_VERSION_1_41:
 *
 * A define that can be used by the C pre-processor to check for features in 1.41
 *
 * Since: 1.41
 */
#define SNAPD_GLIB_VERSION_1_41

/**
 * SNAPD_GLIB_VERSION_1_42:
 *
 * A define that can be used by the C pre-processor to check for features in 1.42
 *
 * Since: 1.42
 */
#define SNAPD_GLIB_VERSION_1_42

/**
 * SNAPD_GLIB_VERSION_1_43:
 *
 * A define that can be used by the C pre-processor to check for features in 1.43
 *
 * Since: 1.43
 */
#define SNAPD_GLIB_VERSION_1_43

/**
 * SNAPD_GLIB_VERSION_1_44:
 *
 * A define that can be used by the C pre-processor to check for features in 1.44
 *
 * Since: 1.44
 */
#define SNAPD_GLIB_VERSION_1_44

/**
 * SNAPD_GLIB_VERSION_1_45:
 *
 * A define that can be used by the C pre-processor to check for features in 1.45
 *
 * Since: 1.45
 */
#define SNAPD_GLIB_VERSION_1_45

/**
 * SNAPD_GLIB_VERSION_1_46:
 *
 * A define that can be used by the C pre-processor to check for features in 1.46
 *
 * Since: 1.46
 */
#define SNAPD_GLIB_VERSION_1_46

/**
 * SNAPD_GLIB_VERSION_1_47:
 *
 * A define that can be used by the C pre-processor to check for features in 1.47
 *
 * Since: 1.47
 */
#define SNAPD_GLIB_VERSION_1_47

/**
 * SNAPD_GLIB_VERSION_1_48:
 *
 * A define that can be used by the C pre-processor to check for features in 1.48
 *
 * Since: 1.48
 */
#define SNAPD_GLIB_VERSION_1_48

/**
 * SNAPD_GLIB_VERSION_1_49:
 *
 * A define that can be used by the C pre-processor to check for features in 1.49
 *
 * Since: 1.49
 */
#define SNAPD_GLIB_VERSION_1_49

/**
 * SNAPD_GLIB_VERSION_1_50:
 *
 * A define that can be used by the C pre-processor to check for features in 1.50
 *
 * Since: 1.50
 */
#define SNAPD_GLIB_VERSION_1_50

/**
 * SNAPD_GLIB_VERSION_1_51:
 *
 * A define that can be used by the C pre-processor to check for features in 1.51
 *
 * Since: 1.51
 */
#define SNAPD_GLIB_VERSION_1_51

/**
 * SNAPD_GLIB_VERSION_1_52:
 *
 * A define that can be used by the C pre-processor to check for features in 1.52
 *
 * Since: 1.52
 */
#define SNAPD_GLIB_VERSION_1_52

/**
 * SNAPD_GLIB_VERSION_1_53:
 *
 * A define that can be used by the C pre-processor to check for features in 1.53
 *
 * Since: 1.53
 */
#define SNAPD_GLIB_VERSION_1_53

/**
 * SNAPD_GLIB_VERSION_1_54:
 *
 * A define that can be used by the C pre-processor to check for features in 1.54
 *
 * Since: 1.54
 */
#define SNAPD_GLIB_VERSION_1_54

/**
 * SNAPD_GLIB_VERSION_1_55:
 *
 * A define that can be used by the C pre-processor to check for features in 1.55
 *
 * Since: 1.55
 */
#define SNAPD_GLIB_VERSION_1_55

/**
 * SNAPD_GLIB_VERSION_1_56:
 *
 * A define that can be used by the C pre-processor to check for features in 1.56
 *
 * Since: 1.56
 */
#define SNAPD_GLIB_VERSION_1_56

/**
 * SNAPD_GLIB_VERSION_1_57:
 *
 * A define that can be used by the C pre-processor to check for features in 1.57
 *
 * Since: 1.57
 */
#define SNAPD_GLIB_VERSION_1_57

/**
 * SNAPD_GLIB_VERSION_1_58:
 *
 * A define that can be used by the C pre-processor to check for features in 1.58
 *
 * Since: 1.58
 */
#define SNAPD_GLIB_VERSION_1_58

/**
 * SNAPD_GLIB_VERSION_1_59:
 *
 * A define that can be used by the C pre-processor to check for features in 1.59
 *
 * Since: 1.59
 */
#define SNAPD_GLIB_VERSION_1_59

/**
 * SNAPD_GLIB_VERSION_1_60:
 *
 * A define that can be used by the C pre-processor to check for features in 1.60
 *
 * Since: 1.60
 */
#define SNAPD_GLIB_VERSION_1_60

/**
 * SNAPD_GLIB_VERSION_1_61:
 *
 * A define that can be used by the C pre-processor to check for features in 1.61
 *
 * Since: 1.61
 */
#define SNAPD_GLIB_VERSION_1_61

/**
 * SNAPD_GLIB_VERSION_1_62:
 *
 * A define that can be used by the C pre-processor to check for features in 1.62
 *
 * Since: 1.62
 */
#define SNAPD_GLIB_VERSION_1_62

/**
 * SNAPD_GLIB_VERSION_1_63:
 *
 * A define that can be used by the C pre-processor to check for features in 1.63
 *
 * Since: 1.63
 */
#define SNAPD_GLIB_VERSION_1_63

/**
 * SNAPD_GLIB_VERSION_1_64:
 *
 * A define that can be used by the C pre-processor to check for features in 1.64
 *
 * Since: 1.64
 */
#define SNAPD_GLIB_VERSION_1_64

#endif /* __SNAPD_GLIB_VERSION_H__ */
